@@ -25,20 +25,20 @@ from rdial.events import Events
 
 
 def test_list_tasks():
-    events = Events.read('tests/data/test')
+    events = Events.read('tests/data/test', write_cache=False)
     expect(events.tasks()) == ['task', 'task2']
 
 
 def test_current_running_event():
-    events = Events.read('tests/data/test')
+    events = Events.read('tests/data/test', write_cache=False)
     expect(events.running()) == 'task'
 
 
 def test_no_currently_running_event():
-    events = Events.read('tests/data/test_not_running')
+    events = Events.read('tests/data/test_not_running', write_cache=False)
     expect(events.running()) is False
 
 
 def test_sum_durations_in_database():
-    events = Events.read('tests/data/test_not_running')
+    events = Events.read('tests/data/test_not_running', write_cache=False)
     expect(events.sum()) == timedelta(hours=2, minutes=15)
